"""
Copyright (c) 2022 Saransh Chopra. All rights reserved.

riemapp: Manim powered complex mappings.
"""

from __future__ import annotations

import riemapp.geometry  # noqa: F401
from riemapp.core import ComplexMap  # noqa: F401
from riemapp.version import version as __version__  # noqa: F401
